@@ -13,7 +13,9 @@ use Scalar::Util qw(reftype);
 
 use Devel::hdb::Utils;
 
-our $VERSION = '0.23_11';
+use Devel::hdb::Logger qw(log);
+
+our $VERSION = '0.23_12';
 
 use Exception::Class (
         'Devel::hdb::Client::Exception',
@@ -303,7 +305,9 @@ foreach my $type ( qw(breakpoint action) ) {
             my $url = "${type}s";
             my $query_string = _encode_query_string_for_hash(%filters);
             $url .= '?' . $query_string if length($query_string);
+log("sending GET to $url");
             my $response = $self->_GET($url);
+log("got response from $url: ".$response->code);
             _assert_success($response, "Can't $get_multiple_subname");
 
             return $JSON->decode($response->content);
@@ -598,6 +602,7 @@ sub _assert_success {
     my $response = shift;
     my $error = shift;
     unless ($response->is_success) {
+log("Error $error getting response\n",$response);
         Devel::hdb::Client::Exception::HTTP->throw(
                 error => $error . ': ' . $response->message,
                 http_code => $response->code,
