@@ -8,7 +8,7 @@ our @ISA = qw( HTTP::Server::PSGI );
 
 use Socket qw(IPPROTO_TCP TCP_NODELAY);
 
-our $VERSION = '0.23_11';
+our $VERSION = '0.23_12';
 
 use Devel::hdb::Logger qw(log);
 
@@ -36,6 +36,7 @@ sub accept_loop {
     $app = Plack::Middleware::ContentLength->wrap($app);
     log("got app $app");
 
+    ACCEPT_LOOP:
     while (1) {
         log('Top of accept_loop() loop');
         local $SIG{PIPE} = 'IGNORE';
@@ -67,13 +68,16 @@ sub accept_loop {
             $self->handle_connection($env, $conn, $app);
             log('back from handle_connection(), harakiri: ' . (!! $env->{'psgix.harakiri.commit'}));
             #$conn->close;
-            last if $env->{'psgix.harakiri.commit'};
+            last ACCEPT_LOOP if $env->{'psgix.harakiri.commit'};
+            log('bottom of if-block after accept()');
         } else {
             log("accept() failed: $!");
             my $errno = $! + 0;
             log("   errno $errno");
         }
+        log('bottom of while(1) loop');
     }
+    log('leaving accept_loop()...');
 }
 
 use constant MAX_REQUEST_SIZE => 131072;
